compute_protein_number: Compute protein abundance using the protein ruler methodology

View source: R/proteinRuler.R

compute_protein_numberR Documentation

Compute protein abundance using the protein ruler methodology

Description

Compute protein abundance using the protein ruler methodology

Usage

compute_protein_number(
  df,
  idx_histones,
  pattern_intensity = "^Intensity.",
  col_intensity = NULL,
  col_mass = "Mass",
  col_ID = names(df)[1],
  mass_per_cell_in_g = NULL,
  DNA_mass_per_cell = 5.5209e-12,
  replace_zero_by_na = TRUE
)

Arguments

df

A data.frame containing protein intensities. By default, protein intensity column names start by "Intensity." (use parameter pattern_intensity to change)

idx_histones

Row indexes corresponding to histone proteins

pattern_intensity

Pattern (regular exrpression) used to identfy df's columns containing protein intensity values

col_intensity

Names of intensity columns. Overrides pattern_intensity.

col_mass

Column with protein mass (in kDa)

col_ID

Column with IDs

mass_per_cell_in_g

Compute protein abundance using a constant mass per cell (in g).

DNA_mass_per_cell

Mass of DNA per cell (in g)

replace_zero_by_na

Replace zero-valued intensities by NA.

Value

a list containing the following elements :

copy_number : a data.frame with protein abundances

summary : a data.frame with summary variables

Examples

## Not run: 
data("proteinGroups_CD4_Tcells")
idx_h <- grep("^Histone H", proteinGroups_CD4_Tcells$`Protein names`)
col_mass <- "Mol. weight [kDa]"
res <- compute_protein_number(proteinGroups_CD4_Tcells, 
idx_histones = idx_h, 
col_mass = col_mass)

## End(Not run)

VoisinneG/proteinRuler documentation built on Oct. 13, 2022, 9:47 p.m.