map_proteome: Map protein abundance using protein IDs or gene names

View source: R/proteinRuler.R

map_proteomeR Documentation

Map protein abundance using protein IDs or gene names

Description

Add protein abundance to an InteRactome. For multiple identifiers, the abundance of the first match in the proteome dataset is returned.

Usage

map_proteome(
  df,
  col_ID = "Protein.IDs",
  col_names = "names",
  sep_primary = NULL,
  sep_secondary = NULL,
  proteome_dataset,
  pdata_sep = ";",
  pdata_col_ID = "Protein.IDs",
  pdata_col_gene_name = "Gene.names",
  pdata_col_copy_number = "Copy.Number",
  map_gene_name = FALSE,
  return_indexes = FALSE,
  updateProgress = NULL
)

Arguments

df

a data.frame or a list

col_ID

column of df containing protein IDs

col_names

column of df containing gene names. Only used if map_gene_name = TRUE.

sep_primary

Separator between different proteins in df

sep_secondary

Set of separators used sequentially (from right to left) to identify protein IDs for each protein in df

proteome_dataset

Dataset containing protein abundances.

pdata_sep

Separator between different proteins in proteome_dataset

pdata_col_ID

column of proteome_dataset containing protein IDs

pdata_col_gene_name

column of proteome_dataset containing gene names

pdata_col_copy_number

column of proteome_dataset containing protein abundances

map_gene_name

logical, map protein using gene names rather than protein IDs

return_indexes

logical, return vector of matching indexes

updateProgress

used to display progress in shiny apps protein abundances (in log10)

Examples

names <- LETTERS
names[3] <- "Z;A"
copies <- runif(length(LETTERS), 0, 100)
proteome <- data.frame(names, copies, stringsAsFactors = FALSE)
names(proteome) <- c("Gene.names", "Copy.Number")
df <- data.frame("names" = c("C", "M", "Z", "A", "KL Z;A"))
res <- map_proteome(df, col_names = "names", proteome_dataset = proteome, map_gene_name = TRUE)

VoisinneG/proteinRuler documentation built on Oct. 13, 2022, 9:47 p.m.