| proteinGroups_CD4_Tcells | R Documentation |
A dataset containing the characterization of protein groups identified from lysates of mouse effector CD4+ T cells duting the course of TCR stimulation Samples correspond to Cd4+ T cells from WT mice stimulated by cross-linking of Cd3e and Cd4 for different times (0, 30, 120, 300 and 600 seconds). Samples were frozen, lysed and subjected to MS-MS analysis.
proteinGroups_CD4_Tcells
A data frame with 6404 rows (protein groups) and 120 variables:
See the Maxquant documentation for the description of the different variables
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.