| map_proteome | R Documentation |
Add protein abundance to an InteRactome. For multiple identifiers,
the abundance of the first match in the proteome dataset is returned.
map_proteome( df, col_ID = "Protein.IDs", col_names = "names", sep_primary = NULL, sep_secondary = NULL, proteome_dataset, pdata_sep = ";", pdata_col_ID = "Protein.IDs", pdata_col_gene_name = "Gene.names", pdata_col_copy_number = "Copy.Number", map_gene_name = FALSE, return_indexes = FALSE, updateProgress = NULL )
df |
a data.frame or a list |
col_ID |
column of |
col_names |
column of |
sep_primary |
Separator between different proteins in |
sep_secondary |
Set of separators used sequentially (from right to left) to
identify protein IDs for each protein in |
proteome_dataset |
Dataset containing protein abundances. |
pdata_sep |
Separator between different proteins in |
pdata_col_ID |
column of |
pdata_col_gene_name |
column of |
pdata_col_copy_number |
column of |
map_gene_name |
logical, map protein using gene names rather than protein IDs |
return_indexes |
logical, return vector of matching indexes |
updateProgress |
used to display progress in shiny apps protein abundances (in log10) |
names <- LETTERS
names[3] <- "Z;A"
copies <- runif(length(LETTERS), 0, 100)
proteome <- data.frame(names, copies, stringsAsFactors = FALSE)
names(proteome) <- c("Gene.names", "Copy.Number")
df <- data.frame("names" = c("C", "M", "Z", "A", "KL Z;A"))
res <- map_proteome(df, col_names = "names", proteome_dataset = proteome, map_gene_name = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.